@@ -2,7 +2,7 @@
 |''Name''|TiddlyWebConfig|
 |''Description''|configuration settings for TiddlyWebWiki|
 |''Author''|FND|
-|''Version''|1.2.1|
+|''Version''|1.3.0|
 |''Status''|stable|
 |''Source''|http://svn.tiddlywiki.org/Trunk/association/plugins/TiddlyWebConfig.js|
 |''License''|[[BSD|http://www.opensource.org/licenses/bsd-license.php]]|
@@ -46,18 +46,6 @@ var plugin = config.extensions.tiddlyweb = {
 		} else {
 			return true;
 		}
-	},
-	// NB: pseudo-binaries are considered non-binary here
-	isBinary: function(tiddler) {
-		var type = tiddler.fields["server.content-type"];
-		return type ? !this.isTextual(type) : false;
-	},
-	isTextual: function(ctype) {
-		return ctype.indexOf("text/") == 0 || this.endsWith(ctype, "+xml");
-	},
-	endsWith: function(str, suffix) {
-		return str.length >= suffix.length &&
-			str.substr(str.length - suffix.length) == suffix;
 	}
 };
 
@@ -82,7 +70,8 @@ config.commands.deleteTiddler.isEnabled = function(tiddler) {
 
 // hijack option macro to disable username editing
 var _optionMacro = config.macros.option.handler;
-config.macros.option.handler = function(place, macroName, params, wikifier, paramString) {
+config.macros.option.handler = function(place, macroName, params, wikifier,
+		paramString) {
 	if(params[0] == "txtUserName") {
 		params[0] = "options." + params[0];
 		var self = this;
@@ -99,7 +88,7 @@ config.macros.option.handler = function(place, macroName, params, wikifier, para
 // hijack isReadOnly to take into account permissions and content type
 var _isReadOnly = Tiddler.prototype.isReadOnly;
 Tiddler.prototype.isReadOnly = function() {
-	return _isReadOnly.apply(this, arguments) || plugin.isBinary(this) ||
+	return _isReadOnly.apply(this, arguments) ||
 		!plugin.hasPermission("write", this);
 };
 
